@@ -70,7 +70,7 @@ if [ $EXPIRE -lt $LIMIT ]; then
     mv -f --backup=numbered pki/reqs/$CERT_CN.req oldCERTS
     mv -f --backup=numbered $CERT_FILE oldCERTS
     mv -f --backup=numbered $KEY_FILE  oldCERTS
-    ./easyrsa --days=$DAYS build-client-full $CERT_CN nopass
+    ./easyrsa --batch --days=$DAYS build-serverClient-full $CERT_CN nopass
     cp -a pki/issued/$CERT_CN.crt $CERT_FILE
     cp -a pki/private/$CERT_CN.key $KEY_FILE
     chmod g+r $KEY_FILE
